#hhp-container
{
	position: relative;
	width: 870px;
	height: 500px;
}

#sessions-container
{
	width: 200px;
	position: absolute;
	top: 3px;
	left: 0px;
}

#sessions-add, .sessions-session, #sessions-all
{
	background-color: #fff;
	border: 1px solid #aaa;
	padding: 8px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	margin-bottom: 5px;
}


#sessions-add, #sessions-all
{
	background-color: #ccc;
}

#sessions-all
{
	margin-top: 20px;
}

#sessions-add a, #sessions-all a
{
	color: #fff !important;
	font-size: 11px;
}

#sessions-container a
{
	color: #ccc;
	position: relative;
	display: block;
	font-size: 11px;
}

#sessions-container .sessions-session
{
	position: relative;
}

#sessions-container a.delete
{
	position: absolute;
	top: 0px;
	right: 0px;
	padding: 0px;
	margin: 3px;
	padding: 3px;
	border: 1px solid #eee;
	width: 7px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

#sessions-container a:hover
{
	color: #e85631 !important;
}

#sessions-container a.delete:hover
{
	border: 1px solid #e85631 !important;
}

.session-active
{
	color: #000 !important;
	font-size: 11px;
	font-weight: bold;

}

#plan-container
{
	width: 650px;

	top: 0px;
	left: 215px;
}

#plan-container-inner
{
	position: relative;
	height: 500px;
}

#content-container
{
	position: absolute;
	top: 0px;
	left: 00px;
	width: 370px;
	height: 500px;
}

#categories
{
	border: 0px;
	font-family: "lucida grande";
}

#categorytabs { margin-bottom: 5px; }

#categories li
{
	font-size: 11px;
	font-family: "lucida grande";
}

#allsessions {
height: 480px; 
overflow: auto;
	border: 1px solid #aaa;
	-moz-border-radius: 4px;
	padding: 20px;
	border-radius: 4px;
}

#fridge
{
	width: 270px;
	height: 500px;
	background-color: #FFF;
	background-image: url('/site_media/fridge/fridge.png');
	position: absolute;
	top: 0px;
	right: 0px;
}

.grabber
{
	display: block;
	width: 52px;
	height: 52px;
	cursor: move;
	border: 4px solid white;
}

.category-icon
{
	display: block;
	width: 52px;
	height: 52px;
	border: 4px solid white;
}

li.ui-corner-top { margin-left: 3px !important; }
.eat-smart { background-image: url('/site_media/img/icon_eatsmart.png'); }
.get-fit { background-image: url('/site_media/img/icon_getfit.png'); }
.look-sharp { background-image: url('/site_media/img/icon_looksharp.png'); }
.think-positive { background-image: url('/site_media/img/icon_thinkpositive.png'); }

.ui-draggable-dragging
{
	cursor: move;
	background-color: #f60;
	border: 4px solid orange;
	z-index: 9999;
}

/*.dropped { border: #f00 solid 1px; }*/

/*
.arrow
{
	display: block;
	width: 18px;
	height: 18px;
}

.open { background-image: url('/site_media/img/arrow-open.png'); }
.closed { background-image: url('/site_media/img/arrow-closed.png'); }
.disabled { color: #ccc; }
*/

.magnet-popup
{
	display: none;
	position: absolute;
	width: 250px;
	background-color: #ffc;
	padding: 5px;
	z-index: 1000;
	border: 1px solid gray;
	margin: 48px 0px 0px 140px;
	opacity: .9;
}

.magnet-popup-close, .magnet-trash
{
	width: 16px;
	height: 16px;
	float: right;
	cursor: pointer;
}

.magnet-popup-close { background: url("/site_media/fridge/icon_close.png") no-repeat; }
.magnet-trash { background: url("/site_media/fridge/icon_delete.png") no-repeat; }
#categories .label { width: 230px; }

.ui-state-disabled .label
{
	display: block;
	position: absolute;
	left: 56px;
	width: 230px;
	padding-left: 10px;
	padding-top: 16px;
	padding-right: 10px;
}

.grabber .label
{
	display: block;
	position: absolute;
	top: -4px;
	left: 56px;
	height: 40px;
	background-color: #fff;
	width: 50px;
	padding-left: 10px;
	padding-top: 20px;
	padding-right: 10px;
	text-overflow: ellipsis;
	white-space: nowrap;
	overflow: hidden;
}
